@@ -3,11 +3,17 @@ from qualang_tools.config.integration_weights_tools import (
     compress_integration_weights,
     plot_integration_weights,
 )
+from qualang_tools.config.waveform_tools import (
+    drag_gaussian_pulse_waveforms,
+    drag_cosine_pulse_waveforms,
+)
 from qualang_tools.config.builder import ConfigBuilder
 from qualang_tools.config.components import *
 from qualang_tools.config.primitive_components import *
 
 __all__ = [
+    "drag_gaussian_pulse_waveforms",
+    "drag_cosine_pulse_waveforms",
     "convert_integration_weights",
     "compress_integration_weights",
     "plot_integration_weights",
